@@ -34,6 +34,7 @@ StickyNotes *stickynotes = NULL;
 static const BonoboUIVerb stickynotes_applet_menu_verbs[] = 
 {
         BONOBO_UI_UNSAFE_VERB ("new_note", menu_new_note_cb),
+        BONOBO_UI_UNSAFE_VERB ("hide_notes", menu_hide_notes_cb),
         BONOBO_UI_UNSAFE_VERB ("destroy_all", menu_destroy_all_cb),
         BONOBO_UI_UNSAFE_VERB ("preferences", menu_preferences_cb),
         BONOBO_UI_UNSAFE_VERB ("help", menu_help_cb),
@@ -74,7 +75,7 @@ static gboolean stickynotes_applet_factory(PanelApplet *panel_applet, const gcha
 
 /* Sticky Notes applet factory */
 PANEL_APPLET_BONOBO_FACTORY("OAFIID:GNOME_StickyNotesApplet_Factory", PANEL_TYPE_APPLET, "stickynotes_applet", VERSION,
-			    stickynotes_applet_factory, NULL);
+			    stickynotes_applet_factory, NULL)
 
 /* colorshift a pixbuf */
 static void
@@ -353,7 +354,6 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	applet->pressed = FALSE;
 
 	applet->menu_tip = NULL;
-	applet->menu_show = NULL;
 
 	/* Expand the applet for Fitts' law complience. */
 	panel_applet_set_flags(panel_applet, PANEL_APPLET_EXPAND_MINOR);
@@ -443,7 +443,7 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 void
 stickynotes_applet_update_prefs (void)
 {
-	int height, click_behavior;
+	int height;
 	gboolean sys_color, sys_font, sticky, force_default;
 	char *font_str;
 	char *color_str, *font_color_str;
@@ -461,8 +461,6 @@ stickynotes_applet_update_prefs (void)
 			GCONF_PATH "/settings/use_system_color", NULL);
 	sys_font = gconf_client_get_bool (stickynotes->gconf,
 			GCONF_PATH "/settings/use_system_font", NULL);
-	click_behavior = gconf_client_get_int (stickynotes->gconf,
-			GCONF_PATH "/settings/click_behavior", NULL);
 	sticky = gconf_client_get_bool (stickynotes->gconf,
 			GCONF_PATH "/settings/sticky", NULL);
 	force_default = gconf_client_get_bool (stickynotes->gconf,
@@ -552,21 +550,24 @@ stickynotes_applet_update_prefs (void)
 
 void stickynotes_applet_update_menus(void)
 {
+	GList *l;
+	gboolean inconsistent = FALSE;
+
 	gboolean locked = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);	
 	gboolean locked_writable = gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
-	
-	gboolean inconsistent = FALSE;
-	gint i;
 
-	for (i = 0; i < g_list_length(stickynotes->notes) && !inconsistent; i++) {
-		StickyNote *note = g_list_nth_data(stickynotes->notes, i);
+	for (l = stickynotes->notes; l != NULL; l = l->next) {
+		StickyNote *note = l->data;
 
-		if (note->locked != locked)
+		if (note->locked != locked) {
 			inconsistent = TRUE;
+			break;
+		}
 	}
 
-	for (i = 0; i < g_list_length(stickynotes->applets); i++) {
-		StickyNotesApplet *applet = g_list_nth_data(stickynotes->applets, i);
+	for (l = stickynotes->applets; l != NULL; l = l->next) {
+		StickyNotesApplet *applet = l->data;
+
 		BonoboUIComponent *popup = panel_applet_get_popup_component(PANEL_APPLET(applet->w_applet));
 		
 		bonobo_ui_component_set_prop(popup, "/commands/lock", "state", locked ? "1" : "0", NULL);
@@ -578,7 +579,6 @@ void stickynotes_applet_update_menus(void)
 void
 stickynotes_applet_update_tooltips (void)
 {
-	int i;
 	int num;
 	char *tooltip, *no_notes;
 	StickyNotesApplet *applet;
@@ -599,8 +599,6 @@ stickynotes_applet_update_tooltips (void)
 			gtk_label_set_text (GTK_LABEL (gtk_bin_get_child (
 						GTK_BIN (applet->menu_tip))),
 				no_notes);
-		if (applet->menu_show)
-			gtk_widget_set_sensitive (applet->menu_show, num);
 	}
 
 	g_free (tooltip);
